From c379059ff4d18c6c26bf463d6f0304af3ab4eede Mon Sep 17 00:00:00 2001
From: Magnus Walbeck <mw@mwalbeck.org>
Date: Mon, 10 Aug 2020 23:09:55 +0200
Subject: [PATCH] Rename project and remove logo

---
 .gitignore                        |   4 +-
 .vscode/extensions.json           |  15 +
 .vscode/settings.json             |   3 +
 README.md                         |  52 ++-
 logo/logo.ase                     | Bin 1053 -> 0 bytes
 logo/logo.png                     | Bin 2514 -> 0 bytes
 {podfox => podweasel}/__init__.py |  19 +-
 poetry.lock                       | 517 ++++++++++++++++++++++++++++++
 poetry.toml                       |   2 +
 pyproject.toml                    |  22 ++
 requirements.txt                  |   5 -
 setup.py                          |  25 --
 12 files changed, 589 insertions(+), 75 deletions(-)
 create mode 100644 .vscode/extensions.json
 create mode 100644 .vscode/settings.json
 delete mode 100644 logo/logo.ase
 delete mode 100644 logo/logo.png
 rename {podfox => podweasel}/__init__.py (97%)
 create mode 100644 poetry.lock
 create mode 100644 poetry.toml
 create mode 100644 pyproject.toml
 delete mode 100644 requirements.txt
 delete mode 100644 setup.py

diff --git a/.gitignore b/.gitignore
index 7c39684..1d17dae 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,3 +1 @@
-*.swp
-.vscode
-.virtualenv
\ No newline at end of file
+.venv
diff --git a/.vscode/extensions.json b/.vscode/extensions.json
new file mode 100644
index 0000000..d1a329d
--- /dev/null
+++ b/.vscode/extensions.json
@@ -0,0 +1,15 @@
+{
+	// See https://go.microsoft.com/fwlink/?LinkId=827846 to learn about workspace recommendations.
+	// Extension identifier format: ${publisher}.${name}. Example: vscode.csharp
+
+	// List of extensions which should be recommended for users of this workspace.
+	"recommendations": [
+		"bungcip.better-toml",
+		"ms-python.python",
+		"coenraads.bracket-pair-colorizer-2"
+	],
+	// List of extensions recommended by VS Code that should not be recommended for users of this workspace.
+	"unwantedRecommendations": [
+		
+	]
+}
diff --git a/.vscode/settings.json b/.vscode/settings.json
new file mode 100644
index 0000000..2edab25
--- /dev/null
+++ b/.vscode/settings.json
@@ -0,0 +1,3 @@
+{
+    "python.pythonPath": "./.venv/bin/python"
+}
diff --git a/README.md b/README.md
index e64d90a..923bd85 100644
--- a/README.md
+++ b/README.md
@@ -1,23 +1,10 @@
-# podfox - podcatching for the terminal.
-![podfox logo](https://raw.githubusercontent.com/brtmr/podfox/62a0a3e745185deee2ee92e1250034d65d863c21/logo/logo.png)
-
+# podweasel - podcatching for the terminal.
 
 A program for managing & catching podcasts from the terminal. 
 
-Work in Progress and unfinished. Use at your own risk.
-
-## Requirements
-requires feedparser, requests, colorama and tqdm
-
-```
-git clone https://github.com/mwalbeck/podfox.git
-cd podfox
-python3 setup.py install
-```
-
 ## Configuration
 
-podfox main configuration file is called `.podfox.json` and should be located in your home directory.
+podweasel main configuration file is called `.podweasel.json` and should be located in your home directory.
 Here is mine: 
 ```
 {
@@ -43,7 +30,7 @@ Here is mine:
 
 ## Directory Structure
 
-In podfox, every podcast is identified with its own `shortname`, which is restricted to lowercase-letters, numbers, and dashes. If the `shortname` is not specifically given during import, it will be derived from the title of the feed. The following shows a directory tree for such a setup, including two podcasts, each with its own feed.json file for bookkeeping.
+In podweasel, every podcast is identified with its own `shortname`, which is restricted to lowercase-letters, numbers, and dashes. If the `shortname` is not specifically given during import, it will be derived from the title of the feed. The following shows a directory tree for such a setup, including two podcasts, each with its own feed.json file for bookkeeping.
  
 ```
 + podcast-directory
@@ -62,36 +49,36 @@ In podfox, every podcast is identified with its own `shortname`, which is restri
 ```
 ## Usage:
 ```
-    podfox.py import <feed-url> [<shortname>]
-    podfox.py update [<shortname>]
-    podfox.py feeds
-    podfox.py episodes <shortname>
-    podfox.py download [<shortname> --how-many=<n>]
+    podweasel.py import <feed-url> [<shortname>]
+    podweasel.py update [<shortname>]
+    podweasel.py feeds
+    podweasel.py episodes <shortname>
+    podweasel.py download [<shortname> --how-many=<n>]
 ```
 ### Import 
 
 To import a new feed use: 
-`podfox.py import <feed-url> [<shortname>]`
+`podweasel.py import <feed-url> [<shortname>]`
 For example, to import the haskell cast feed:
 
-`podfox import http://www.haskellcast.com/feed.xml`
+`podweasel import http://www.haskellcast.com/feed.xml`
 To import the techsnap podcast, and to store the episodes to a specific folder `ts`, use 
 
 
-`podfox import http://feeds.feedburner.com/techsnapmp3 ts`
+`podweasel import http://feeds.feedburner.com/techsnapmp3 ts`
 
 
 ### Update
-`podfox update` will update all feeds (This does not include downloading any new episodes)
+`podweasel update` will update all feeds (This does not include downloading any new episodes)
 
-`podfox update <shortname>` will only update the feed associated with the given `shortname`
+`podweasel update <shortname>` will only update the feed associated with the given `shortname`
 
 ### Feeds 
 
-`podfox feeds` will give an overview over the imported pocasts, and their `shortname`s.
+`podweasel feeds` will give an overview over the imported pocasts, and their `shortname`s.
 In the example: 
 ```
-$ podfox feeds
+$ podweasel feeds
 title                                     |  shortname           
 ================================================================
 TechSNAP MP3                              |  ts                  
@@ -100,10 +87,10 @@ The Haskell Cast                          |  the-haskell-cast
 
 ### Episodes
 
-`podfox episodes <shortname>` will produce a list of episodes available for this podcast, and wether they have been downloaded yet.
+`podweasel episodes <shortname>` will produce a list of episodes available for this podcast, and wether they have been downloaded yet.
 
 ```
-$ podfox episodes ts
+$ podweasel episodes ts
 A Rip in NTP | TechSNAP 237               |  Not Downloaded      
 National Security Breaking Agency | Tech  |  Not Downloaded      
 Catching the Angler | TechSNAP 235        |  Not Downloaded      
@@ -118,7 +105,6 @@ Extortion Startups | TechSNAP 229         |  Not Downloaded
 
 ### Downloading
 
-`podfox download` will download `maxnum` not yet downloaded episodes for every feed (if possible.)
-
-`podfox download ts --how-many=3` will download the 3 newest techsnap podcasts that have not yet been downloaded. (Skipping newer, but already downloaded ones). If the `--how-many` parameter is omitted, the `maxnum` parameter from the configuration file is used instead.
+`podweasel download` will download `maxnum` not yet downloaded episodes for every feed (if possible.)
 
+`podweasel download ts --how-many=3` will download the 3 newest techsnap podcasts that have not yet been downloaded. (Skipping newer, but already downloaded ones). If the `--how-many` parameter is omitted, the `maxnum` parameter from the configuration file is used instead.
diff --git a/poetry.lock b/poetry.lock
new file mode 100644
index 0000000..9fcbefe
--- /dev/null
+++ b/poetry.lock
@@ -0,0 +1,517 @@
+[[package]]
+category = "dev"
+description = "A small Python module for determining appropriate platform-specific dirs, e.g. a \"user data dir\"."
+name = "appdirs"
+optional = false
+python-versions = "*"
+version = "1.4.4"
+
+[[package]]
+category = "dev"
+description = "Atomic file writes."
+marker = "sys_platform == \"win32\""
+name = "atomicwrites"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "1.4.0"
+
+[[package]]
+category = "dev"
+description = "Classes Without Boilerplate"
+name = "attrs"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "19.3.0"
+
+[package.extras]
+azure-pipelines = ["coverage", "hypothesis", "pympler", "pytest (>=4.3.0)", "six", "zope.interface", "pytest-azurepipelines"]
+dev = ["coverage", "hypothesis", "pympler", "pytest (>=4.3.0)", "six", "zope.interface", "sphinx", "pre-commit"]
+docs = ["sphinx", "zope.interface"]
+tests = ["coverage", "hypothesis", "pympler", "pytest (>=4.3.0)", "six", "zope.interface"]
+
+[[package]]
+category = "dev"
+description = "The uncompromising code formatter."
+name = "black"
+optional = false
+python-versions = ">=3.6"
+version = "19.10b0"
+
+[package.dependencies]
+appdirs = "*"
+attrs = ">=18.1.0"
+click = ">=6.5"
+pathspec = ">=0.6,<1"
+regex = "*"
+toml = ">=0.9.4"
+typed-ast = ">=1.4.0"
+
+[package.extras]
+d = ["aiohttp (>=3.3.2)", "aiohttp-cors"]
+
+[[package]]
+category = "main"
+description = "Python package for providing Mozilla's CA Bundle."
+name = "certifi"
+optional = false
+python-versions = "*"
+version = "2020.6.20"
+
+[[package]]
+category = "main"
+description = "Universal encoding detector for Python 2 and 3"
+name = "chardet"
+optional = false
+python-versions = "*"
+version = "3.0.4"
+
+[[package]]
+category = "dev"
+description = "Composable command line interface toolkit"
+name = "click"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*"
+version = "7.1.2"
+
+[[package]]
+category = "main"
+description = "Cross-platform colored terminal text."
+name = "colorama"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*"
+version = "0.4.3"
+
+[[package]]
+category = "main"
+description = "Pythonic argument parser, that will make you smile"
+name = "docopt"
+optional = false
+python-versions = "*"
+version = "0.6.2"
+
+[[package]]
+category = "main"
+description = "Universal feed parser, handles RSS 0.9x, RSS 1.0, RSS 2.0, CDF, Atom 0.3, and Atom 1.0 feeds"
+name = "feedparser"
+optional = false
+python-versions = "*"
+version = "5.2.1"
+
+[[package]]
+category = "dev"
+description = "the modular source code checker: pep8 pyflakes and co"
+name = "flake8"
+optional = false
+python-versions = "!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*,>=2.7"
+version = "3.8.3"
+
+[package.dependencies]
+mccabe = ">=0.6.0,<0.7.0"
+pycodestyle = ">=2.6.0a1,<2.7.0"
+pyflakes = ">=2.2.0,<2.3.0"
+
+[package.dependencies.importlib-metadata]
+python = "<3.8"
+version = "*"
+
+[[package]]
+category = "main"
+description = "Internationalized Domain Names in Applications (IDNA)"
+name = "idna"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "2.10"
+
+[[package]]
+category = "dev"
+description = "Read metadata from Python packages"
+marker = "python_version < \"3.8\""
+name = "importlib-metadata"
+optional = false
+python-versions = "!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*,!=3.4.*,>=2.7"
+version = "1.7.0"
+
+[package.dependencies]
+zipp = ">=0.5"
+
+[package.extras]
+docs = ["sphinx", "rst.linker"]
+testing = ["packaging", "pep517", "importlib-resources (>=1.3)"]
+
+[[package]]
+category = "dev"
+description = "McCabe checker, plugin for flake8"
+name = "mccabe"
+optional = false
+python-versions = "*"
+version = "0.6.1"
+
+[[package]]
+category = "dev"
+description = "More routines for operating on iterables, beyond itertools"
+name = "more-itertools"
+optional = false
+python-versions = ">=3.5"
+version = "8.4.0"
+
+[[package]]
+category = "dev"
+description = "Core utilities for Python packages"
+name = "packaging"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "20.4"
+
+[package.dependencies]
+pyparsing = ">=2.0.2"
+six = "*"
+
+[[package]]
+category = "dev"
+description = "Utility library for gitignore style pattern matching of file paths."
+name = "pathspec"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*"
+version = "0.8.0"
+
+[[package]]
+category = "dev"
+description = "plugin and hook calling mechanisms for python"
+name = "pluggy"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "0.13.1"
+
+[package.dependencies]
+[package.dependencies.importlib-metadata]
+python = "<3.8"
+version = ">=0.12"
+
+[package.extras]
+dev = ["pre-commit", "tox"]
+
+[[package]]
+category = "dev"
+description = "library with cross-python path, ini-parsing, io, code, log facilities"
+name = "py"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "1.9.0"
+
+[[package]]
+category = "dev"
+description = "Python style guide checker"
+name = "pycodestyle"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "2.6.0"
+
+[[package]]
+category = "dev"
+description = "passive checker of Python programs"
+name = "pyflakes"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*"
+version = "2.2.0"
+
+[[package]]
+category = "dev"
+description = "Python parsing module"
+name = "pyparsing"
+optional = false
+python-versions = ">=2.6, !=3.0.*, !=3.1.*, !=3.2.*"
+version = "2.4.7"
+
+[[package]]
+category = "dev"
+description = "pytest: simple powerful testing with Python"
+name = "pytest"
+optional = false
+python-versions = ">=3.5"
+version = "5.4.3"
+
+[package.dependencies]
+atomicwrites = ">=1.0"
+attrs = ">=17.4.0"
+colorama = "*"
+more-itertools = ">=4.0.0"
+packaging = "*"
+pluggy = ">=0.12,<1.0"
+py = ">=1.5.0"
+wcwidth = "*"
+
+[package.dependencies.importlib-metadata]
+python = "<3.8"
+version = ">=0.12"
+
+[package.extras]
+checkqa-mypy = ["mypy (v0.761)"]
+testing = ["argcomplete", "hypothesis (>=3.56)", "mock", "nose", "requests", "xmlschema"]
+
+[[package]]
+category = "dev"
+description = "Alternative regular expression module, to replace re."
+name = "regex"
+optional = false
+python-versions = "*"
+version = "2020.7.14"
+
+[[package]]
+category = "main"
+description = "Python HTTP for Humans."
+name = "requests"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*"
+version = "2.24.0"
+
+[package.dependencies]
+certifi = ">=2017.4.17"
+chardet = ">=3.0.2,<4"
+idna = ">=2.5,<3"
+urllib3 = ">=1.21.1,<1.25.0 || >1.25.0,<1.25.1 || >1.25.1,<1.26"
+
+[package.extras]
+security = ["pyOpenSSL (>=0.14)", "cryptography (>=1.3.4)"]
+socks = ["PySocks (>=1.5.6,<1.5.7 || >1.5.7)", "win-inet-pton"]
+
+[[package]]
+category = "dev"
+description = "Python 2 and 3 compatibility utilities"
+name = "six"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*"
+version = "1.15.0"
+
+[[package]]
+category = "dev"
+description = "Python Library for Tom's Obvious, Minimal Language"
+name = "toml"
+optional = false
+python-versions = "*"
+version = "0.10.1"
+
+[[package]]
+category = "main"
+description = "Fast, Extensible Progress Meter"
+name = "tqdm"
+optional = false
+python-versions = ">=2.6, !=3.0.*, !=3.1.*"
+version = "4.48.2"
+
+[package.extras]
+dev = ["py-make (>=0.1.0)", "twine", "argopt", "pydoc-markdown"]
+
+[[package]]
+category = "dev"
+description = "a fork of Python 2 and 3 ast modules with type comment support"
+name = "typed-ast"
+optional = false
+python-versions = "*"
+version = "1.4.1"
+
+[[package]]
+category = "main"
+description = "HTTP library with thread-safe connection pooling, file post, and more."
+name = "urllib3"
+optional = false
+python-versions = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, <4"
+version = "1.25.10"
+
+[package.extras]
+brotli = ["brotlipy (>=0.6.0)"]
+secure = ["certifi", "cryptography (>=1.3.4)", "idna (>=2.0.0)", "pyOpenSSL (>=0.14)", "ipaddress"]
+socks = ["PySocks (>=1.5.6,<1.5.7 || >1.5.7,<2.0)"]
+
+[[package]]
+category = "dev"
+description = "Measures the displayed width of unicode strings in a terminal"
+name = "wcwidth"
+optional = false
+python-versions = "*"
+version = "0.2.5"
+
+[[package]]
+category = "dev"
+description = "Backport of pathlib-compatible object wrapper for zip files"
+marker = "python_version < \"3.8\""
+name = "zipp"
+optional = false
+python-versions = ">=3.6"
+version = "3.1.0"
+
+[package.extras]
+docs = ["sphinx", "jaraco.packaging (>=3.2)", "rst.linker (>=1.9)"]
+testing = ["jaraco.itertools", "func-timeout"]
+
+[metadata]
+content-hash = "b7bdc0271e75f0cd26a2b56cea4c0d2a6b6cf655e9a8c961445f2d256ee23bdf"
+lock-version = "1.0"
+python-versions = "^3.6"
+
+[metadata.files]
+appdirs = [
+    {file = "appdirs-1.4.4-py2.py3-none-any.whl", hash = "sha256:a841dacd6b99318a741b166adb07e19ee71a274450e68237b4650ca1055ab128"},
+    {file = "appdirs-1.4.4.tar.gz", hash = "sha256:7d5d0167b2b1ba821647616af46a749d1c653740dd0d2415100fe26e27afdf41"},
+]
+atomicwrites = [
+    {file = "atomicwrites-1.4.0-py2.py3-none-any.whl", hash = "sha256:6d1784dea7c0c8d4a5172b6c620f40b6e4cbfdf96d783691f2e1302a7b88e197"},
+    {file = "atomicwrites-1.4.0.tar.gz", hash = "sha256:ae70396ad1a434f9c7046fd2dd196fc04b12f9e91ffb859164193be8b6168a7a"},
+]
+attrs = [
+    {file = "attrs-19.3.0-py2.py3-none-any.whl", hash = "sha256:08a96c641c3a74e44eb59afb61a24f2cb9f4d7188748e76ba4bb5edfa3cb7d1c"},
+    {file = "attrs-19.3.0.tar.gz", hash = "sha256:f7b7ce16570fe9965acd6d30101a28f62fb4a7f9e926b3bbc9b61f8b04247e72"},
+]
+black = [
+    {file = "black-19.10b0-py36-none-any.whl", hash = "sha256:1b30e59be925fafc1ee4565e5e08abef6b03fe455102883820fe5ee2e4734e0b"},
+    {file = "black-19.10b0.tar.gz", hash = "sha256:c2edb73a08e9e0e6f65a0e6af18b059b8b1cdd5bef997d7a0b181df93dc81539"},
+]
+certifi = [
+    {file = "certifi-2020.6.20-py2.py3-none-any.whl", hash = "sha256:8fc0819f1f30ba15bdb34cceffb9ef04d99f420f68eb75d901e9560b8749fc41"},
+    {file = "certifi-2020.6.20.tar.gz", hash = "sha256:5930595817496dd21bb8dc35dad090f1c2cd0adfaf21204bf6732ca5d8ee34d3"},
+]
+chardet = [
+    {file = "chardet-3.0.4-py2.py3-none-any.whl", hash = "sha256:fc323ffcaeaed0e0a02bf4d117757b98aed530d9ed4531e3e15460124c106691"},
+    {file = "chardet-3.0.4.tar.gz", hash = "sha256:84ab92ed1c4d4f16916e05906b6b75a6c0fb5db821cc65e70cbd64a3e2a5eaae"},
+]
+click = [
+    {file = "click-7.1.2-py2.py3-none-any.whl", hash = "sha256:dacca89f4bfadd5de3d7489b7c8a566eee0d3676333fbb50030263894c38c0dc"},
+    {file = "click-7.1.2.tar.gz", hash = "sha256:d2b5255c7c6349bc1bd1e59e08cd12acbbd63ce649f2588755783aa94dfb6b1a"},
+]
+colorama = [
+    {file = "colorama-0.4.3-py2.py3-none-any.whl", hash = "sha256:7d73d2a99753107a36ac6b455ee49046802e59d9d076ef8e47b61499fa29afff"},
+    {file = "colorama-0.4.3.tar.gz", hash = "sha256:e96da0d330793e2cb9485e9ddfd918d456036c7149416295932478192f4436a1"},
+]
+docopt = [
+    {file = "docopt-0.6.2.tar.gz", hash = "sha256:49b3a825280bd66b3aa83585ef59c4a8c82f2c8a522dbe754a8bc8d08c85c491"},
+]
+feedparser = [
+    {file = "feedparser-5.2.1.tar.bz2", hash = "sha256:ce875495c90ebd74b179855449040003a1beb40cd13d5f037a0654251e260b02"},
+    {file = "feedparser-5.2.1.tar.gz", hash = "sha256:bd030652c2d08532c034c27fcd7c85868e7fa3cb2b17f230a44a6bbc92519bf9"},
+    {file = "feedparser-5.2.1.zip", hash = "sha256:cd2485472e41471632ed3029d44033ee420ad0b57111db95c240c9160a85831c"},
+]
+flake8 = [
+    {file = "flake8-3.8.3-py2.py3-none-any.whl", hash = "sha256:15e351d19611c887e482fb960eae4d44845013cc142d42896e9862f775d8cf5c"},
+    {file = "flake8-3.8.3.tar.gz", hash = "sha256:f04b9fcbac03b0a3e58c0ab3a0ecc462e023a9faf046d57794184028123aa208"},
+]
+idna = [
+    {file = "idna-2.10-py2.py3-none-any.whl", hash = "sha256:b97d804b1e9b523befed77c48dacec60e6dcb0b5391d57af6a65a312a90648c0"},
+    {file = "idna-2.10.tar.gz", hash = "sha256:b307872f855b18632ce0c21c5e45be78c0ea7ae4c15c828c20788b26921eb3f6"},
+]
+importlib-metadata = [
+    {file = "importlib_metadata-1.7.0-py2.py3-none-any.whl", hash = "sha256:dc15b2969b4ce36305c51eebe62d418ac7791e9a157911d58bfb1f9ccd8e2070"},
+    {file = "importlib_metadata-1.7.0.tar.gz", hash = "sha256:90bb658cdbbf6d1735b6341ce708fc7024a3e14e99ffdc5783edea9f9b077f83"},
+]
+mccabe = [
+    {file = "mccabe-0.6.1-py2.py3-none-any.whl", hash = "sha256:ab8a6258860da4b6677da4bd2fe5dc2c659cff31b3ee4f7f5d64e79735b80d42"},
+    {file = "mccabe-0.6.1.tar.gz", hash = "sha256:dd8d182285a0fe56bace7f45b5e7d1a6ebcbf524e8f3bd87eb0f125271b8831f"},
+]
+more-itertools = [
+    {file = "more-itertools-8.4.0.tar.gz", hash = "sha256:68c70cc7167bdf5c7c9d8f6954a7837089c6a36bf565383919bb595efb8a17e5"},
+    {file = "more_itertools-8.4.0-py3-none-any.whl", hash = "sha256:b78134b2063dd214000685165d81c154522c3ee0a1c0d4d113c80361c234c5a2"},
+]
+packaging = [
+    {file = "packaging-20.4-py2.py3-none-any.whl", hash = "sha256:998416ba6962ae7fbd6596850b80e17859a5753ba17c32284f67bfff33784181"},
+    {file = "packaging-20.4.tar.gz", hash = "sha256:4357f74f47b9c12db93624a82154e9b120fa8293699949152b22065d556079f8"},
+]
+pathspec = [
+    {file = "pathspec-0.8.0-py2.py3-none-any.whl", hash = "sha256:7d91249d21749788d07a2d0f94147accd8f845507400749ea19c1ec9054a12b0"},
+    {file = "pathspec-0.8.0.tar.gz", hash = "sha256:da45173eb3a6f2a5a487efba21f050af2b41948be6ab52b6a1e3ff22bb8b7061"},
+]
+pluggy = [
+    {file = "pluggy-0.13.1-py2.py3-none-any.whl", hash = "sha256:966c145cd83c96502c3c3868f50408687b38434af77734af1e9ca461a4081d2d"},
+    {file = "pluggy-0.13.1.tar.gz", hash = "sha256:15b2acde666561e1298d71b523007ed7364de07029219b604cf808bfa1c765b0"},
+]
+py = [
+    {file = "py-1.9.0-py2.py3-none-any.whl", hash = "sha256:366389d1db726cd2fcfc79732e75410e5fe4d31db13692115529d34069a043c2"},
+    {file = "py-1.9.0.tar.gz", hash = "sha256:9ca6883ce56b4e8da7e79ac18787889fa5206c79dcc67fb065376cd2fe03f342"},
+]
+pycodestyle = [
+    {file = "pycodestyle-2.6.0-py2.py3-none-any.whl", hash = "sha256:2295e7b2f6b5bd100585ebcb1f616591b652db8a741695b3d8f5d28bdc934367"},
+    {file = "pycodestyle-2.6.0.tar.gz", hash = "sha256:c58a7d2815e0e8d7972bf1803331fb0152f867bd89adf8a01dfd55085434192e"},
+]
+pyflakes = [
+    {file = "pyflakes-2.2.0-py2.py3-none-any.whl", hash = "sha256:0d94e0e05a19e57a99444b6ddcf9a6eb2e5c68d3ca1e98e90707af8152c90a92"},
+    {file = "pyflakes-2.2.0.tar.gz", hash = "sha256:35b2d75ee967ea93b55750aa9edbbf72813e06a66ba54438df2cfac9e3c27fc8"},
+]
+pyparsing = [
+    {file = "pyparsing-2.4.7-py2.py3-none-any.whl", hash = "sha256:ef9d7589ef3c200abe66653d3f1ab1033c3c419ae9b9bdb1240a85b024efc88b"},
+    {file = "pyparsing-2.4.7.tar.gz", hash = "sha256:c203ec8783bf771a155b207279b9bccb8dea02d8f0c9e5f8ead507bc3246ecc1"},
+]
+pytest = [
+    {file = "pytest-5.4.3-py3-none-any.whl", hash = "sha256:5c0db86b698e8f170ba4582a492248919255fcd4c79b1ee64ace34301fb589a1"},
+    {file = "pytest-5.4.3.tar.gz", hash = "sha256:7979331bfcba207414f5e1263b5a0f8f521d0f457318836a7355531ed1a4c7d8"},
+]
+regex = [
+    {file = "regex-2020.7.14-cp27-cp27m-win32.whl", hash = "sha256:e46d13f38cfcbb79bfdb2964b0fe12561fe633caf964a77a5f8d4e45fe5d2ef7"},
+    {file = "regex-2020.7.14-cp27-cp27m-win_amd64.whl", hash = "sha256:6961548bba529cac7c07af2fd4d527c5b91bb8fe18995fed6044ac22b3d14644"},
+    {file = "regex-2020.7.14-cp36-cp36m-manylinux1_i686.whl", hash = "sha256:c50a724d136ec10d920661f1442e4a8b010a4fe5aebd65e0c2241ea41dbe93dc"},
+    {file = "regex-2020.7.14-cp36-cp36m-manylinux1_x86_64.whl", hash = "sha256:8a51f2c6d1f884e98846a0a9021ff6861bdb98457879f412fdc2b42d14494067"},
+    {file = "regex-2020.7.14-cp36-cp36m-manylinux2010_i686.whl", hash = "sha256:9c568495e35599625f7b999774e29e8d6b01a6fb684d77dee1f56d41b11b40cd"},
+    {file = "regex-2020.7.14-cp36-cp36m-manylinux2010_x86_64.whl", hash = "sha256:51178c738d559a2d1071ce0b0f56e57eb315bcf8f7d4cf127674b533e3101f88"},
+    {file = "regex-2020.7.14-cp36-cp36m-win32.whl", hash = "sha256:9eddaafb3c48e0900690c1727fba226c4804b8e6127ea409689c3bb492d06de4"},
+    {file = "regex-2020.7.14-cp36-cp36m-win_amd64.whl", hash = "sha256:14a53646369157baa0499513f96091eb70382eb50b2c82393d17d7ec81b7b85f"},
+    {file = "regex-2020.7.14-cp37-cp37m-manylinux1_i686.whl", hash = "sha256:1269fef3167bb52631ad4fa7dd27bf635d5a0790b8e6222065d42e91bede4162"},
+    {file = "regex-2020.7.14-cp37-cp37m-manylinux1_x86_64.whl", hash = "sha256:d0a5095d52b90ff38592bbdc2644f17c6d495762edf47d876049cfd2968fbccf"},
+    {file = "regex-2020.7.14-cp37-cp37m-manylinux2010_i686.whl", hash = "sha256:4c037fd14c5f4e308b8370b447b469ca10e69427966527edcab07f52d88388f7"},
+    {file = "regex-2020.7.14-cp37-cp37m-manylinux2010_x86_64.whl", hash = "sha256:bc3d98f621898b4a9bc7fecc00513eec8f40b5b83913d74ccb445f037d58cd89"},
+    {file = "regex-2020.7.14-cp37-cp37m-win32.whl", hash = "sha256:46bac5ca10fb748d6c55843a931855e2727a7a22584f302dd9bb1506e69f83f6"},
+    {file = "regex-2020.7.14-cp37-cp37m-win_amd64.whl", hash = "sha256:0dc64ee3f33cd7899f79a8d788abfbec168410be356ed9bd30bbd3f0a23a7204"},
+    {file = "regex-2020.7.14-cp38-cp38-manylinux1_i686.whl", hash = "sha256:5ea81ea3dbd6767873c611687141ec7b06ed8bab43f68fad5b7be184a920dc99"},
+    {file = "regex-2020.7.14-cp38-cp38-manylinux1_x86_64.whl", hash = "sha256:bbb332d45b32df41200380fff14712cb6093b61bd142272a10b16778c418e98e"},
+    {file = "regex-2020.7.14-cp38-cp38-manylinux2010_i686.whl", hash = "sha256:c11d6033115dc4887c456565303f540c44197f4fc1a2bfb192224a301534888e"},
+    {file = "regex-2020.7.14-cp38-cp38-manylinux2010_x86_64.whl", hash = "sha256:75aaa27aa521a182824d89e5ab0a1d16ca207318a6b65042b046053cfc8ed07a"},
+    {file = "regex-2020.7.14-cp38-cp38-win32.whl", hash = "sha256:d6cff2276e502b86a25fd10c2a96973fdb45c7a977dca2138d661417f3728341"},
+    {file = "regex-2020.7.14-cp38-cp38-win_amd64.whl", hash = "sha256:7a2dd66d2d4df34fa82c9dc85657c5e019b87932019947faece7983f2089a840"},
+    {file = "regex-2020.7.14.tar.gz", hash = "sha256:3a3af27a8d23143c49a3420efe5b3f8cf1a48c6fc8bc6856b03f638abc1833bb"},
+]
+requests = [
+    {file = "requests-2.24.0-py2.py3-none-any.whl", hash = "sha256:fe75cc94a9443b9246fc7049224f75604b113c36acb93f87b80ed42c44cbb898"},
+    {file = "requests-2.24.0.tar.gz", hash = "sha256:b3559a131db72c33ee969480840fff4bb6dd111de7dd27c8ee1f820f4f00231b"},
+]
+six = [
+    {file = "six-1.15.0-py2.py3-none-any.whl", hash = "sha256:8b74bedcbbbaca38ff6d7491d76f2b06b3592611af620f8426e82dddb04a5ced"},
+    {file = "six-1.15.0.tar.gz", hash = "sha256:30639c035cdb23534cd4aa2dd52c3bf48f06e5f4a941509c8bafd8ce11080259"},
+]
+toml = [
+    {file = "toml-0.10.1-py2.py3-none-any.whl", hash = "sha256:bda89d5935c2eac546d648028b9901107a595863cb36bae0c73ac804a9b4ce88"},
+    {file = "toml-0.10.1.tar.gz", hash = "sha256:926b612be1e5ce0634a2ca03470f95169cf16f939018233a670519cb4ac58b0f"},
+]
+tqdm = [
+    {file = "tqdm-4.48.2-py2.py3-none-any.whl", hash = "sha256:1a336d2b829be50e46b84668691e0a2719f26c97c62846298dd5ae2937e4d5cf"},
+    {file = "tqdm-4.48.2.tar.gz", hash = "sha256:564d632ea2b9cb52979f7956e093e831c28d441c11751682f84c86fc46e4fd21"},
+]
+typed-ast = [
+    {file = "typed_ast-1.4.1-cp35-cp35m-manylinux1_i686.whl", hash = "sha256:73d785a950fc82dd2a25897d525d003f6378d1cb23ab305578394694202a58c3"},
+    {file = "typed_ast-1.4.1-cp35-cp35m-manylinux1_x86_64.whl", hash = "sha256:aaee9905aee35ba5905cfb3c62f3e83b3bec7b39413f0a7f19be4e547ea01ebb"},
+    {file = "typed_ast-1.4.1-cp35-cp35m-win32.whl", hash = "sha256:0c2c07682d61a629b68433afb159376e24e5b2fd4641d35424e462169c0a7919"},
+    {file = "typed_ast-1.4.1-cp35-cp35m-win_amd64.whl", hash = "sha256:4083861b0aa07990b619bd7ddc365eb7fa4b817e99cf5f8d9cf21a42780f6e01"},
+    {file = "typed_ast-1.4.1-cp36-cp36m-macosx_10_9_x86_64.whl", hash = "sha256:269151951236b0f9a6f04015a9004084a5ab0d5f19b57de779f908621e7d8b75"},
+    {file = "typed_ast-1.4.1-cp36-cp36m-manylinux1_i686.whl", hash = "sha256:24995c843eb0ad11a4527b026b4dde3da70e1f2d8806c99b7b4a7cf491612652"},
+    {file = "typed_ast-1.4.1-cp36-cp36m-manylinux1_x86_64.whl", hash = "sha256:fe460b922ec15dd205595c9b5b99e2f056fd98ae8f9f56b888e7a17dc2b757e7"},
+    {file = "typed_ast-1.4.1-cp36-cp36m-win32.whl", hash = "sha256:4e3e5da80ccbebfff202a67bf900d081906c358ccc3d5e3c8aea42fdfdfd51c1"},
+    {file = "typed_ast-1.4.1-cp36-cp36m-win_amd64.whl", hash = "sha256:249862707802d40f7f29f6e1aad8d84b5aa9e44552d2cc17384b209f091276aa"},
+    {file = "typed_ast-1.4.1-cp37-cp37m-macosx_10_9_x86_64.whl", hash = "sha256:8ce678dbaf790dbdb3eba24056d5364fb45944f33553dd5869b7580cdbb83614"},
+    {file = "typed_ast-1.4.1-cp37-cp37m-manylinux1_i686.whl", hash = "sha256:c9e348e02e4d2b4a8b2eedb48210430658df6951fa484e59de33ff773fbd4b41"},
+    {file = "typed_ast-1.4.1-cp37-cp37m-manylinux1_x86_64.whl", hash = "sha256:bcd3b13b56ea479b3650b82cabd6b5343a625b0ced5429e4ccad28a8973f301b"},
+    {file = "typed_ast-1.4.1-cp37-cp37m-win32.whl", hash = "sha256:d5d33e9e7af3b34a40dc05f498939f0ebf187f07c385fd58d591c533ad8562fe"},
+    {file = "typed_ast-1.4.1-cp37-cp37m-win_amd64.whl", hash = "sha256:0666aa36131496aed8f7be0410ff974562ab7eeac11ef351def9ea6fa28f6355"},
+    {file = "typed_ast-1.4.1-cp38-cp38-macosx_10_15_x86_64.whl", hash = "sha256:d205b1b46085271b4e15f670058ce182bd1199e56b317bf2ec004b6a44f911f6"},
+    {file = "typed_ast-1.4.1-cp38-cp38-manylinux1_i686.whl", hash = "sha256:6daac9731f172c2a22ade6ed0c00197ee7cc1221aa84cfdf9c31defeb059a907"},
+    {file = "typed_ast-1.4.1-cp38-cp38-manylinux1_x86_64.whl", hash = "sha256:498b0f36cc7054c1fead3d7fc59d2150f4d5c6c56ba7fb150c013fbc683a8d2d"},
+    {file = "typed_ast-1.4.1-cp38-cp38-win32.whl", hash = "sha256:715ff2f2df46121071622063fc7543d9b1fd19ebfc4f5c8895af64a77a8c852c"},
+    {file = "typed_ast-1.4.1-cp38-cp38-win_amd64.whl", hash = "sha256:fc0fea399acb12edbf8a628ba8d2312f583bdbdb3335635db062fa98cf71fca4"},
+    {file = "typed_ast-1.4.1-cp39-cp39-macosx_10_15_x86_64.whl", hash = "sha256:d43943ef777f9a1c42bf4e552ba23ac77a6351de620aa9acf64ad54933ad4d34"},
+    {file = "typed_ast-1.4.1.tar.gz", hash = "sha256:8c8aaad94455178e3187ab22c8b01a3837f8ee50e09cf31f1ba129eb293ec30b"},
+]
+urllib3 = [
+    {file = "urllib3-1.25.10-py2.py3-none-any.whl", hash = "sha256:e7983572181f5e1522d9c98453462384ee92a0be7fac5f1413a1e35c56cc0461"},
+    {file = "urllib3-1.25.10.tar.gz", hash = "sha256:91056c15fa70756691db97756772bb1eb9678fa585d9184f24534b100dc60f4a"},
+]
+wcwidth = [
+    {file = "wcwidth-0.2.5-py2.py3-none-any.whl", hash = "sha256:beb4802a9cebb9144e99086eff703a642a13d6a0052920003a230f3294bbe784"},
+    {file = "wcwidth-0.2.5.tar.gz", hash = "sha256:c4d647b99872929fdb7bdcaa4fbe7f01413ed3d98077df798530e5b04f116c83"},
+]
+zipp = [
+    {file = "zipp-3.1.0-py3-none-any.whl", hash = "sha256:aa36550ff0c0b7ef7fa639055d797116ee891440eac1a56f378e2d3179e0320b"},
+    {file = "zipp-3.1.0.tar.gz", hash = "sha256:c599e4d75c98f6798c509911d08a22e6c021d074469042177c8c86fb92eefd96"},
+]
diff --git a/poetry.toml b/poetry.toml
new file mode 100644
index 0000000..ab1033b
--- /dev/null
+++ b/poetry.toml
@@ -0,0 +1,2 @@
+[virtualenvs]
+in-project = true
diff --git a/pyproject.toml b/pyproject.toml
new file mode 100644
index 0000000..d80ea20
--- /dev/null
+++ b/pyproject.toml
@@ -0,0 +1,22 @@
+[tool.poetry]
+name = "podweasel"
+version = "0.1.0"
+description = ""
+authors = ["Magnus Walbeck <mw@mwalbeck.org>"]
+
+[tool.poetry.dependencies]
+python = "^3.6"
+requests = "^2.24.0"
+tqdm = "^4.48.2"
+feedparser = "^5.2.1"
+docopt = "^0.6.2"
+colorama = "^0.4.3"
+
+[tool.poetry.dev-dependencies]
+pytest = "^5.2"
+black = "^19.10b0"
+flake8 = "^3.8.3"
+
+[build-system]
+requires = ["poetry>=0.12"]
+build-backend = "poetry.masonry.api"
diff --git a/requirements.txt b/requirements.txt
deleted file mode 100644
index d36ccb2..0000000
--- a/requirements.txt
+++ /dev/null
@@ -1,5 +0,0 @@
-colorama>=0.3.7,<=0.3.9
-docopt==0.6.2
-feedparser==5.2.1
-requests>=2.11.1,<=2.18.1
-tqdm==4.14.0
\ No newline at end of file
diff --git a/setup.py b/setup.py
deleted file mode 100644
index 7b82ed9..0000000
--- a/setup.py
+++ /dev/null
@@ -1,25 +0,0 @@
-from setuptools import setup
-
-with open('requirements.txt') as f:
-    required = f.read().splitlines()
-
-setup(name='podfox',
-    version='0.1.3',
-    description='Podcatcher for the terminal',
-    url='https://github.com/mwalbeck/podfox',
-    license='GPLv3',
-    packages=['podfox'],
-    zip_safe=False,
-    entry_points={
-        'console_scripts': [
-            'podfox = podfox.__init__:main'
-        ]
-    },
-    install_requires=[
-        'colorama>=0.3.7,<=0.3.9',
-        'docopt==0.6.2',
-        'feedparser==5.2.1',
-        'requests>=2.11.1,<=2.18.1',
-        'tqdm==4.14.0',
-        ],
-    )
diff --git a/logo/logo.ase b/logo/logo.ase
deleted file mode 100644
index 80a613ab30dc554d145fa2654ceeef5b1815cd78..0000000000000000000000000000000000000000
GIT binary patch
literal 0
HcmV?d00001

literal 1053
zcmcJNTTByK9ET5zF+RG!sL`P!;)TEhik0HnXs`on)o7y9R;z+sx|?b(!FERQ9*xyZ
zh$sq}7|SX|3!>nKplm`SxCDrmZRH|WsTgfqV=b**?D!*INPPDs^UZlW-}gT=vqK4a
z`A-O0M8b)Pgb+e9@Qg3f`1ZH#E>9$6_+#i#Yd0)2L_e%yzd8j%!bMBK)eDw`nTc^A
zza<HD=pw<cE196DsRSJHE(I^W*$8SL#e(7@Ex0!4PjJ)P2rzzmA}E#Sg0VY~f=cZx
zFuha&)oo6&wPzF*um~x&+yjpnoCI?;8Zd3kCNOW+Y4B!zJlM509kg@xAYZ%&JiRwo
z&|sF(u^S#64ntr9<f9$os75k+5sOk}q7i|pLmIjeg(BpPwFm+#kN`jAFhdI`gs?#s
zHf9pxVt+0qkjZ4-F5{m4qPRs92$>`zWKi%30`}il20nqI%-z){Z;G9Mc$aJ?y^nc)
z^!c%=Y}Oy1vgaojE~^QNIy_;z$}Uw~SIzToV?);{Z+N4`^7_O^w&(jPqjR&={hc5B
z#SJUygClO^4o^&Gnv&0PTMY%hG1~ZtS~h>C#ds|t<|H-ZG92RW+)wS>U2<K_SeWY8
zZq6x}ZMW*Z`MMNdaV{Z{o$zj<GMRPC<hE{e@7%&jqv_z@<N#A`q7FICDvo|EXX$~v
z*@G!Ab<$lwHS{22f3T%v##5@UqtZsDrQ?(o)2Kem8a|lqo<jReeKuomgMIf*c2-{o
zmp?Se^2H~fZK`cy-oGk%;-&OOpNje~e$YqL7nY`0%N-LH(O0>DgP-HhCPrJ?Vn^#$
zTH~r}*76Oh61DTcgbmRe$N9fpHyPEV_PWSDrcp`x-&SQ7JrKyw&pXfC+0KEy;5M5%
zZ++ESujHXU{B}EA%bh9d^pyG(MJ`p({3_`%t&l4MH8Q<RXW(0gA|wYM_zTn7+UmuM
zz_eojE$QP6y^b%gKt;2T^~r*UVKsjvt?@|t+jjR<ql$k)6*@YK{ikx@wcW8%&4wKo
z#;F_W-yGx&<&3l5T-VngRzp=jsbGAPjeHa5vq{)SO{e+)6#kj-mNYn-{_zWpzjr#4
Jl4WI|z5@A>p$Py0

diff --git a/logo/logo.png b/logo/logo.png
deleted file mode 100644
index f1b0424af55c08a8b5610f42021cebccea8911ea..0000000000000000000000000000000000000000
GIT binary patch
literal 0
HcmV?d00001

literal 2514
zcma)8Sx{346n!jVF+gcM0z;*!b#Sz3P+QS}3V}>nT9HjifP~5vEtv+?AhJewoj9nq
zBnn206$()ViGkpd1fjq<6v~pt3MK@L+0Xzc1OiF=Qp=RKI=+wh^XARH=bn4cx$oSe
zgI_qVabE)ffMaM#a1;Po+yb8%I~(u~K^)=@0QOfyg9BquUwbirkB}JW-YXqG60$j?
z1}6-NV#A-sC}SFtv3E<h`rUHAVvP!;ZD^)EM4yeekGsp?Qi+V6ZKhL_+^*r!0ZCh5
zcslniWy=!jak~8x`B(OSa$)f}CENE@tE*@iAfHa>AOL`Qb-jf%>LPG<eFzZjyb0K7
z_W|&}wfz~pBI^L_K+E-A93g_8XSlBor+Pc#Gqdr%1G>di*E|!oTuZAbeowvWuS#Bj
zSp*ged~>0axu_tmt4f!3V_8CLe?&gW^`_qzr>F7G$WjIB{;4z!Ql}V>P$kMDs7(Y}
z-F&{-DC6bgrNsqHdZsvzJ?g*Vt;NkK&An?n_=jSX4)5{HjYI0D2hgKBmfVNPadE@>
zi?`9oB;<Hx+voTn1~1iWzyF0#^@LJ#F)9cl!1LR1r23ZS45pAQ6T%&aqB9r2_NF*p
zfAg>_c+6Zl^Y}B9vqZ%>)7Q23WTUG`>vPITyO3fXJxVC7(Howf(qK2$Z}-ydq@ryj
z-n@a;yvkeo%{)^x>E-nF(@x)ZOcT1iLBZ-A!fKa(&A}qPVrXzIVx0zC5P~PoK-dd0
z+!5f^A`WP<Bzez=|K9xSzAM7mZPv~<e8!^wTgCWP+V6AU9X)zf9VWZZX+Ngt#`5sX
z<5T&gPbK*yQ~CJ6X@9KAZ!=HbBfVXxu70^Z!5|U6`(Y`VwEBVy&gj6%UI>G;MN5{A
zG2}?Rp|n6SJR3PGs;*KN^*rjoT&Et(DJ&d|OtLxFC_2&=@8ZFLw%P8<nOMd6oOX1i
zy<c#Gu38S&y6O{Nfx7u-p8$PcD4{Wwx>~)dxSECA6oN01XYz2+DhI`?(B-%hngur8
z)WI=sk4{LA=a3VSzT}x>6V*Om5QNiwkI7-b%s=Nc;_AU&n(wP?(hbm9_|7;QoB?+*
zEi}x-4GcATfuT^bc2i+x$`%wsP+Rt@_;z7BDkAsi>e`bKx+FJP?Eg^&dUGj{tb5ey
zi;2i=ut?nn?xSR7<Ex@zwIJLEqJk>XwyDf{xI-U4FAAAO%8NnzvS4Nibxopvu_9Id
z>1V@w$xr&MSqMtZ<sdS~7`!tk!=$V*y~|k%w`J9qDJ_Et0ySQLvzs5|>eSmJAFA5?
z|BPA<%#8a>VnYo>bhA54VtlO8<}4b^o2s}t6}kuqci4=G2$NM*TnLk4$tIU_77XrI
z1hJ&Pe_pvW09>uID-blE2398QhjH%XNLQX%c7yXO#upz7I(?-nr%|sH=`CsaSFHX)
zb<a_-<U`>qm<@3^$QuI$Cn&WeKDYlTeE&PxN;Xs7ji}5WHQJ4ZrNz~;rhUDWQ%z(I
zw~L;-LrR=`H`~_Xjszu`jxH{4as_Be-P-;25B6L#?uBBVhf&?zu0FY046~U?$$s~w
zMYUx<3W`$-Cb{`eXWwJ<#qc}8c3<#Pg__nu(x|i|jU)E~McyxH(XDl>0f}d5ev?Ar
z=_9`}ib_mlf5r1Rb&!YzuG@l_L(K#Jj80|(5p?!J;Hm^vCeWN?YSpdXIN<5Ol}<3|
z2nMb|1mW(1Jd>p-Sl;xpDufN!o{2F?tWuf!od5<xkbpc_c_Z)iSy}~w=`p6!j?g@@
zk|w>mJ2c+R7hB6k-NIidi<j1%Kcojkf<xVcMIa$6bZ}5yIru_-V4ayZy&BHMER_}u
z>st3fA^&nhT78TBVvnWO`5O=%7M~U$of$Z>Kmq-UGwS=0qH~dk4i`5z{P}wyR}MCc
xc^(U1&!D*jFxtW$+Pa}0G!DW7fWYVs-t{oGJy&|X6#Q2MLeU3<@1l~6{sdv{oudE%

diff --git a/podfox/__init__.py b/podweasel/__init__.py
similarity index 97%
rename from podfox/__init__.py
rename to podweasel/__init__.py
index 264fff2..763cb48 100755
--- a/podfox/__init__.py
+++ b/podweasel/__init__.py
@@ -1,17 +1,17 @@
 #!/usr/bin/env python3
 """podfox - podcatcher for the terminal
 
 
 Usage:
-    podfox.py import <feed-url> [<shortname>] [-c=<path>]
-    podfox.py update [<shortname>] [-c=<path>]
-    podfox.py feeds [-c=<path>]
-    podfox.py episodes <shortname> [-c=<path>]
-    podfox.py download [<shortname> --how-many=<n>] [-c=<path>]
-    podfox.py rename <shortname> <newname> [-c=<path>]
+    podweasel.py import <feed-url> [<shortname>] [-c=<path>]
+    podweasel.py update [<shortname>] [-c=<path>]
+    podweasel.py feeds [-c=<path>]
+    podweasel.py episodes <shortname> [-c=<path>]
+    podweasel.py download [<shortname> --how-many=<n>] [-c=<path>]
+    podweasel.py rename <shortname> <newname> [-c=<path>]
 
 Options:
-    -c --config=<path>    Specify an alternate config file [default: ~/.podfox.json]
+    -c --config=<path>    Specify an alternate config file [default: ~/.podweasel.json]
     -h --help     Show this help
 """
 # (C) 2015 Bastian Reitemeier
@@ -393,7 +393,7 @@ def download_single(folder, url, filename):
 
 def available_feeds():
     '''
     podfox will save each feed to its own folder. Each folder should
     contain a json configuration file describing which elements
     have been downloaded already, and how many will be kept.
     '''
@@ -531,5 +531,6 @@ def main():
     if arguments['rename']:
         rename(arguments['<shortname>'], arguments['<newname>'])
 
+
 if __name__ == "__main__":
     main()
@@ -1,17 +1,17 @@
 #!/usr/bin/env python3
-"""podfox - podcatcher for the terminal
+"""podweasel - podcatcher for the terminal
 
 
@@ -393,7 +393,7 @@ def download_single(folder, url, filename):
 def available_feeds():
     '''
-    podfox will save each feed to its own folder. Each folder should
+    podweasel will save each feed to its own folder. Each folder should
     contain a json configuration file describing which elements
     have been downloaded already, and how many will be kept.